]> de.git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
defaulting to nodinput mode again due to problems with dinput mode
authorhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Wed, 1 Dec 2004 06:07:14 +0000 (06:07 +0000)
committerhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Wed, 1 Dec 2004 06:07:14 +0000 (06:07 +0000)
git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@4803 d7cf8633-e32d-0410-b094-e92efae38249

darkplaces.txt
vid_wgl.c

index 24140f6199454188205c306e123800f5d19e088e..ba8813d0d533bf77fd9481c9600e9de8f7ee0f77 100644 (file)
@@ -12,6 +12,11 @@ I am not very good at writing documentation, so this readme is organized as a
 feature list, with information on each feature, I hope it is still adequate
 documentation.
 
 feature list, with information on each feature, I hope it is still adequate
 documentation.
 
+Input Tips:
+If mouse movement is jerky but framerate is high, try typing "gl_finish 1"
+(without quotes) into the console (makes cpu wait for gpu before ending frame,
+which gives lousy input drivers a chance to catch up).
+
 Graphics Tips:
 Visit the Color Control submenu of Options, it's near the top, fiddle with
 gamma (or grey level if using the color levels mode) until the grey box
 Graphics Tips:
 Visit the Color Control submenu of Options, it's near the top, fiddle with
 gamma (or grey level if using the color levels mode) until the grey box
@@ -264,10 +269,10 @@ Video: -width <pixels> performs +vid_width <pixels> and also +vid_height <pixels
 Video: -window performs +vid_fullscreen 0
 Windows DirectSound: -primarysound locks the sound hardware for exclusive use
 Windows DirectSound: -snoforceformat uses the format that DirectSound returns, rather than forcing it
 Video: -window performs +vid_fullscreen 0
 Windows DirectSound: -primarysound locks the sound hardware for exclusive use
 Windows DirectSound: -snoforceformat uses the format that DirectSound returns, rather than forcing it
-Windows GDI Input: -noforcemaccel disables setting of mouse acceleration (-nodinput only, windows only)
-Windows GDI Input: -noforcemparms disables setting of mouse parameters (-nodinput only, windows only)
-Windows GDI Input: -noforcemspd disables setting of mouse speed (-nodinput only, windows only)
-Windows Input: -nodinput disables DirectInput for mouse/joystick input, gl_finish 1 mode recommended if this option is used as otherwise it tends to stutter due to input backlog.
+Windows GDI Input: -noforcemaccel disables setting of mouse acceleration (not used with -dinput, windows only)
+Windows GDI Input: -noforcemparms disables setting of mouse parameters (not used with -dinput, windows only)
+Windows GDI Input: -noforcemspd disables setting of mouse speed (not used with -dinput, windows only)
+Windows Input: -dinput enables DirectInput for mouse/joystick input
 Windows Input: -nojoy disables joystick support, may be a small speed increase
 Windows Sound: -sndspeed <hz> chooses 44100 hz, 22100 hz, or 11025 hz sound output rate
 Windows Sound: -wavonly uses wave sound instead of DirectSound
 Windows Input: -nojoy disables joystick support, may be a small speed increase
 Windows Sound: -sndspeed <hz> chooses 44100 hz, 22100 hz, or 11025 hz sound output rate
 Windows Sound: -wavonly uses wave sound instead of DirectSound
index c6e0ff7404ecb9b4686385284611c67ff919e861..d5cd194e7c8bf9ab61232d0dbd9933db566e4efb 100644 (file)
--- a/vid_wgl.c
+++ b/vid_wgl.c
@@ -1256,8 +1256,8 @@ void IN_StartupMouse (void)
 
        mouseinitialized = true;
 
 
        mouseinitialized = true;
 
-// COMMANDLINEOPTION: Windows Input: -nodinput disables DirectInput for mouse/joystick input, gl_finish 1 mode recommended if this option is used as otherwise it tends to stutter due to input backlog.
-       if (!COM_CheckParm ("-nodinput"))
+// COMMANDLINEOPTION: Windows Input: -dinput enables DirectInput for mouse/joystick input
+       if (COM_CheckParm ("-dinput"))
        {
                dinput = IN_InitDInput ();
 
        {
                dinput = IN_InitDInput ();
 
@@ -1277,18 +1277,18 @@ void IN_StartupMouse (void)
 
                if (mouseparmsvalid)
                {
 
                if (mouseparmsvalid)
                {
// COMMANDLINEOPTION: Windows GDI Input: -noforcemspd disables setting of mouse speed (-nodinput only, windows only)
                        if ( COM_CheckParm ("-noforcemspd") )
                                newmouseparms[2] = originalmouseparms[2];
 
                        if ( COM_CheckParm ("-noforcemspd") )
                                newmouseparms[2] = originalmouseparms[2];
 
// COMMANDLINEOPTION: Windows GDI Input: -noforcemaccel disables setting of mouse acceleration (-nodinput only, windows only)
                        if ( COM_CheckParm ("-noforcemaccel") )
                        {
                                newmouseparms[0] = originalmouseparms[0];
                                newmouseparms[1] = originalmouseparms[1];
                        }
 
                        if ( COM_CheckParm ("-noforcemaccel") )
                        {
                                newmouseparms[0] = originalmouseparms[0];
                                newmouseparms[1] = originalmouseparms[1];
                        }
 
// COMMANDLINEOPTION: Windows GDI Input: -noforcemparms disables setting of mouse parameters (-nodinput only, windows only)
                        if ( COM_CheckParm ("-noforcemparms") )
                        {
                                newmouseparms[0] = originalmouseparms[0];
@@ -1277,18 +1277,18 @@ void IN_StartupMouse (void)
                if (mouseparmsvalid)
                {
-// COMMANDLINEOPTION: Windows GDI Input: -noforcemspd disables setting of mouse speed (-nodinput only, windows only)
+// COMMANDLINEOPTION: Windows GDI Input: -noforcemspd disables setting of mouse speed (not used with -dinput, windows only)
                        if ( COM_CheckParm ("-noforcemspd") )
                                newmouseparms[2] = originalmouseparms[2];
@@ -1277,18 +1277,18 @@ void IN_StartupMouse (void)
                                newmouseparms[2] = originalmouseparms[2];
 
-// COMMANDLINEOPTION: Windows GDI Input: -noforcemaccel disables setting of mouse acceleration (-nodinput only, windows only)
+// COMMANDLINEOPTION: Windows GDI Input: -noforcemaccel disables setting of mouse acceleration (not used with -dinput, windows only)
                        if ( COM_CheckParm ("-noforcemaccel") )
                        {
@@ -1277,18 +1277,18 @@ void IN_StartupMouse (void)
                        }
 
-// COMMANDLINEOPTION: Windows GDI Input: -noforcemparms disables setting of mouse parameters (-nodinput only, windows only)
+// COMMANDLINEOPTION: Windows GDI Input: -noforcemparms disables setting of mouse parameters (not used with -dinput, windows only)
                        if ( COM_CheckParm ("-noforcemparms") )
                        {
                        if ( COM_CheckParm ("-noforcemparms") )
                        {
                                newmouseparms[0] = originalmouseparms[0];